@@ -4,8 +4,9 @@ import sys
 
 from .bake import bake_schema, get_field_for
 from .metadata import decimal_metadata, metadata
-from .missing import MISSING, Missing
+from .missing import MISSING
 from .naming_case import CAMEL_CASE, CAPITAL_CAMEL_CASE, DEFAULT_CASE, CamelCase, CapitalCamelCase, NamingCase
+from .options import NoneValueHandling, options
 from .serialization import EmptySchema, dump, dump_many, load, load_many, schema
 
 __all__: tuple[str, ...] = (
@@ -15,7 +16,8 @@ __all__: tuple[str, ...] = (
     "CAMEL_CASE",
     "CamelCase",
     "get_field_for",
-    "Missing",
+    "options",
+    "NoneValueHandling",
     "MISSING",
     "NamingCase",
     "DEFAULT_CASE",
@@ -29,7 +31,7 @@ __all__: tuple[str, ...] = (
     "decimal_metadata",
 )
 
-__version__ = "0.0.6"
+__version__ = "0.0.11"
 
 version = f"{__version__}, Python {sys.version}"
 
