@@ -21,11 +21,12 @@ from .fields import (
     int_field,
     list_field,
     nested_field,
+    raw_field,
     str_field,
     uuid_field,
 )
-from .missing import MISSING, Missing
-from .naming_case import DEFAULT_CASE, NamingCase
+from .naming_case import NamingCase
+from .options import NoneValueHandling, get_options_for
 
 _T = TypeVar("_T")
 _MARSHMALLOW_VERSION_MAJOR = int(m.__version__.split(".")[0])
@@ -34,15 +35,19 @@ _MARSHMALLOW_VERSION_MAJOR = int(m.__version__.split(".")[0])
 def bake_schema(
     cls: Type[_T],
     *,
-    naming_case: NamingCase = DEFAULT_CASE,
+    naming_case: NamingCase | None = None,
 ) -> Type[m.Schema]:
     if not dataclasses.is_dataclass(cls):
         raise ValueError(f"{cls} is not a dataclass")
 
+    options = get_options_for(cls)
+    if naming_case is None:
+        naming_case = options.naming_case
+
     fields = dataclasses.fields(cls)
     schema_class = type(
         cls.__name__,
-        (_get_base_schema(cls),),
+        (_get_base_schema(cls, options.none_value_handling),),
         {
             field.name: get_field_for(
                 field.type,
@@ -62,6 +67,9 @@ def get_field_for(
     *,
     naming_case: NamingCase,
 ) -> m.fields.Field:
+    if type is Any:
+        return raw_field(**metadata)
+
     type = _substitute_any_to_open_generic(type)
 
     if typing_inspect.is_union_type(type):
@@ -114,14 +122,16 @@ def get_field_for(
 
 if _MARSHMALLOW_VERSION_MAJOR >= 3:
 
-    def _get_base_schema(cls: Type[_T]) -> Type[m.Schema]:
+    def _get_base_schema(cls: Type[_T], none_value_handling: NoneValueHandling) -> Type[m.Schema]:
         class _Schema(m.Schema):
             class Meta:
                 unknown = m.EXCLUDE
 
             @m.post_dump
             def remove_none_values(self, data: dict[str, Any], **_: Any) -> dict[str, Any]:
-                return {key: value for key, value in data.items() if value is not None}
+                if none_value_handling == NoneValueHandling.IGNORE:
+                    return {key: value for key, value in data.items() if value is not None}
+                return data
 
             @m.post_load
             def post_load(self, data: dict[str, Any], **_: Any) -> Any:
@@ -131,11 +141,13 @@ if _MARSHMALLOW_VERSION_MAJOR >= 3:
 
 else:
 
-    def _get_base_schema(cls: Type[_T]) -> Type[m.Schema]:
+    def _get_base_schema(cls: Type[_T], none_value_handling: NoneValueHandling) -> Type[m.Schema]:
         class _Schema(m.Schema):  # type: ignore
             @m.post_dump  # type: ignore
             def remove_none_values(self, data: dict[str, Any]) -> dict[str, Any]:
-                return {key: value for key, value in data.items() if value is not None}
+                if none_value_handling == NoneValueHandling.IGNORE:
+                    return {key: value for key, value in data.items() if value is not None}
+                return data
 
             @m.post_load  # type: ignore
             def post_load(self, data: dict[str, Any]) -> Any:
@@ -144,13 +156,11 @@ else:
         return _Schema
 
 
-def _get_field_default(field: dataclasses.Field[_T]) -> _T | Missing:
+def _get_field_default(field: dataclasses.Field[_T]) -> Any:
     default_factory = field.default_factory
     if default_factory is not dataclasses.MISSING:  # type: ignore
         raise ValueError(f"Default factory is not supported for {field}")
-    if field.default is not dataclasses.MISSING:
-        return field.default
-    return MISSING
+    return field.default
 
 
 class _FieldFactory(Generic[_T]):
@@ -159,7 +169,7 @@ class _FieldFactory(Generic[_T]):
         *,
         required: bool,
         name: str,
-        default: _T | Missing,
+        default: Any,
         **kwargs: Any,
     ) -> m.fields.Field:
         ...
