@@ -1,33 +1,40 @@
+import dataclasses
 import datetime
-import decimal
 import enum
-import uuid
 from typing import Any, Callable, Iterable, Type, cast
 
 import marshmallow as m
 import marshmallow.validate
 
-from .missing import MISSING, Missing
-
 _MARSHMALLOW_VERSION_MAJOR = int(m.__version__.split(".")[0])
 
 
 def str_field(
     *,
     required: bool,
-    default: str | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
-    if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
+    if default is m.missing:
+        return m.fields.Str(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
 
-        return m.fields.String(required=True, **data_key_fields(name))
+    if required:
+        if default is None:
+            raise ValueError("Default value cannot be none")
+
+        return m.fields.String(required=True, validate=validate, **data_key_fields(name))
 
     return m.fields.Str(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -35,19 +42,29 @@ def str_field(
 def bool_field(
     *,
     required: bool,
-    default: bool | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
-    if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
+    if default is m.missing:
+        return m.fields.Bool(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
 
-        return m.fields.Boolean(required=True, **data_key_fields(name))
+    if required:
+        if default is None:
+            raise ValueError("Default value cannot be none")
+
+        return m.fields.Boolean(required=True, validate=validate, **data_key_fields(name))
 
     return m.fields.Bool(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -55,22 +72,36 @@ def bool_field(
 def decimal_field(
     *,
     required: bool,
-    default: decimal.Decimal | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
     places: int = 2,
     as_string: bool = True,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if default is m.missing:
+        return m.fields.Decimal(
+            allow_none=not required,
+            as_string=as_string,
+            places=places,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
-        return m.fields.Decimal(required=True, as_string=as_string, places=places, **data_key_fields(name))
+        if default is None:
+            raise ValueError("Default value cannot be none")
+        return m.fields.Decimal(
+            required=True, as_string=as_string, places=places, validate=validate, **data_key_fields(name)
+        )
 
     return m.fields.Decimal(
         allow_none=True,
         as_string=as_string,
         places=places,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -78,18 +109,28 @@ def decimal_field(
 def int_field(
     *,
     required: bool,
-    default: int | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if default is m.missing:
+        return m.fields.Int(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
-        return m.fields.Int(required=True, **data_key_fields(name))
+        if default is None:
+            raise ValueError("Default value cannot be none")
+        return m.fields.Int(required=True, validate=validate, **data_key_fields(name))
 
     return m.fields.Int(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -97,18 +138,28 @@ def int_field(
 def float_field(
     *,
     required: bool,
-    default: float | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if default is m.missing:
+        return m.fields.Float(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
-        return m.fields.Float(required=True, **data_key_fields(name))
+        if default is None:
+            raise ValueError("Default value cannot be none")
+        return m.fields.Float(required=True, validate=validate, **data_key_fields(name))
 
     return m.fields.Float(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -116,18 +167,28 @@ def float_field(
 def uuid_field(
     *,
     required: bool,
-    default: uuid.UUID | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if default is m.missing:
+        return m.fields.UUID(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
-        return m.fields.UUID(required=True, **data_key_fields(name))
+        if default is None:
+            raise ValueError("Default value cannot be none")
+        return m.fields.UUID(required=True, validate=validate, **data_key_fields(name))
 
     return m.fields.UUID(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -135,18 +196,28 @@ def uuid_field(
 def datetime_field(
     *,
     required: bool,
-    default: datetime.datetime | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if default is m.missing:
+        return DateTimeField(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
-        return DateTimeField(required=True, **data_key_fields(name))
+        if default is None:
+            raise ValueError("Default value cannot be none")
+        return DateTimeField(required=True, validate=validate, **data_key_fields(name))
 
     return DateTimeField(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -154,18 +225,28 @@ def datetime_field(
 def date_field(
     *,
     required: bool,
-    default: datetime.date | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if default is m.missing:
+        return m.fields.Date(
+            allow_none=not required,
+            validate=validate,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
-        return m.fields.Date(required=True, **data_key_fields(name))
+        if default is None:
+            raise ValueError("Default value cannot be none")
+        return m.fields.Date(required=True, validate=validate, **data_key_fields(name))
 
     return m.fields.Date(
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -174,17 +255,30 @@ def nested_field(
     nested_schema: Type[m.Schema],
     *,
     required: bool,
-    default: Any | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if validate is not None:
+        raise ValueError("Validation is not supported")
+
+    if default is m.missing:
+        return m.fields.Nested(
+            nested_schema,
+            allow_none=not required,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
+        if default is None:
+            raise ValueError("Default value cannot be none")
         return m.fields.Nested(nested_schema, required=True, **data_key_fields(name))
 
-    if default is not MISSING and default is not None:
-        raise ValueError("Default values is not supported for required fields")
+    if default is not dataclasses.MISSING and default is not None:
+        raise ValueError("Default value is not supported for nested field")
+
     return m.fields.Nested(
         nested_schema,
         allow_none=True,
@@ -197,17 +291,30 @@ def list_field(
     field: m.fields.Field,
     *,
     required: bool,
-    default: Any | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if validate is not None:
+        raise ValueError("Validation is not supported")
+
+    if default is m.missing:
+        return m.fields.List(
+            field,
+            allow_none=not required,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
+        if default is None:
+            raise ValueError("Default value cannot be none")
         return m.fields.List(field, required=True, **data_key_fields(name))
 
-    if default is not MISSING and default is not None:
-        raise ValueError("Default values is not supported for required fields")
+    if default is not dataclasses.MISSING and default is not None:
+        raise ValueError("Default value is not supported for list field")
+
     return m.fields.List(
         field,
         allow_none=True,
@@ -219,17 +326,22 @@ def list_field(
 def dict_field(
     *,
     required: bool,
-    default: Any | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
     name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
     **_: Any,
 ) -> m.fields.Field:
+    if validate is not None:
+        raise ValueError("Validation is not supported")
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
+        if default is None:
+            raise ValueError("Default value cannot be none")
         return m.fields.Dict(required=True, **data_key_fields(name))
 
-    if default is not MISSING and default is not None:
-        raise ValueError("Default values is not supported for required fields")
+    if default is not dataclasses.MISSING and default is not None:
+        raise ValueError("Default value is not supported for dict field")
+
     return m.fields.Dict(
         allow_none=True,
         **default_fields(None),
@@ -242,11 +354,23 @@ def enum_field(
     *,
     required: bool,
     name: str | None = None,
-    default: Any | None | Missing = MISSING,
+    default: Any = dataclasses.MISSING,
+    validate: Callable[[Any], Any] | None = None,
 ) -> marshmallow.fields.Field:
+    if default is m.missing:
+        return EnumField(
+            enum_type=enum_type,
+            allow_none=not required,
+            **default_fields(m.missing),
+            **data_key_fields(name),
+        )
+
+    if validate is not None:
+        raise ValueError("Validation is not supported")
+
     if required:
-        if default is not MISSING:
-            raise ValueError("Default values is not supported for required fields")
+        if default is None:
+            raise ValueError("Default value cannot be none")
         return EnumField(
             enum_type=enum_type,
             required=True,
@@ -256,7 +380,22 @@ def enum_field(
     return EnumField(
         enum_type=enum_type,
         allow_none=True,
-        **default_fields(None if default is MISSING else default),
+        **default_fields(None if default is dataclasses.MISSING else default),
+        **data_key_fields(name),
+    )
+
+
+def raw_field(
+    *,
+    default: Any = dataclasses.MISSING,
+    name: str | None = None,
+    validate: Callable[[Any], Any] | None = None,
+    **_: Any,
+) -> m.fields.Field:
+    return m.fields.Raw(
+        allow_none=True,
+        validate=validate,
+        **default_fields(None if default is dataclasses.MISSING else default),
         **data_key_fields(name),
     )
 
@@ -386,7 +525,7 @@ if _MARSHMALLOW_VERSION_MAJOR >= 3:
                     raise ValueError(f"There is enum value, which is not a string: {choice}")
 
         @staticmethod
-        def _validate_default(enum_type: Any, default: enum.Enum | None | Missing, allow_none: bool) -> None:
+        def _validate_default(enum_type: Any, default: Any, allow_none: bool) -> None:
             if default is m.missing:
                 return
 
@@ -519,7 +658,7 @@ else:
                     raise ValueError(f"There is enum value, which is not a string: {choice}")
 
         @staticmethod
-        def _validate_default(enum_type: Any, default: enum.Enum | None | Missing, allow_none: bool) -> None:
+        def _validate_default(enum_type: Any, default: Any, allow_none: bool) -> None:
             if default is m.missing:
                 return
 
