@@ -1,23 +1,27 @@
-from typing import Any, Mapping
+from typing import Any, Callable, Mapping
 
-from .missing import MISSING, Missing
+from .missing import MISSING
 
 
 def metadata(
     *,
-    name: str | Missing = MISSING,
+    name: str = MISSING,
+    validate: Callable[[Any], Any] | None = None,
 ) -> Mapping[Any, Any]:
     result: dict[Any, Any] = {}
     if name is not MISSING:
         result.update(name=name)
+    if validate is not None:
+        result.update(validate=validate)
     return result
 
 
 def decimal_metadata(
     *,
-    name: str | Missing = MISSING,
-    places: int | Missing = MISSING,
-    as_string: bool | Missing = MISSING,
+    name: str = MISSING,
+    places: int = MISSING,
+    as_string: bool = MISSING,
+    validate: Callable[[Any], Any] | None = None,
 ) -> Mapping[Any, Any]:
     result: dict[Any, Any] = {}
     if name is not MISSING:
@@ -26,4 +30,6 @@ def decimal_metadata(
         result.update(places=places)
     if as_string is not MISSING:
         result.update(as_string=as_string)
+    if validate is not None:
+        result.update(validate=validate)
     return result
